#!/usr/bin/env perl
#
# cat pfam | pfam.pl
#

use strict;
use warnings;
use Common;

my $entry = "";
while (my $l = <STDIN>) {
  if ($l =~ /^#=GF AC +(\S+)/) {
    $entry = $1;
    $entry =~ s/\.\S+$//;
  }
  elsif ($l =~ /^#=GF RM +(\S+)/) {
    pmid($1);
  }
  elsif ($l =~ /^#=GF DR +([^\;]+)\; +([^\;]+)/) {
    dr($1,$2);
  }
  elsif ($l =~ /^#=GF CC +(\S+)/) {
    my $s = substr($l,9);
    while (my $t = <STDIN>) {
      if ($t =~ /^COMPND /) {
        $s .= substr($t,10);
      }
      else {
        $l = $t;
        last;
      }
    }
    cc($s);
  }
  if ($l =~ /^#=GS /) {
    my $s = substr($l,5);
    gs($s);
  }
  if ($l =~ /^\/\//) {
    $entry = "";
  }
}

sub pmid {
  my $pmid = shift;
  print "pf:$entry\tpmid:$pmid\n";
}

sub dr {
  my ($db,$id) = @_;
  $db = lc $db;
  $id = $2;
  if ($db eq 'prosite') {
    print "pf:$entry\tpdoc:$id\n";
  }
  elsif ($db eq 'prosite_profile') {
    print "pf:$entry\tps:$id\n";
  }
  elsif ($db eq 'mim') {
    print "pf:$entry\tomim:$id\n";
  }
  #elsif ($db eq 'cazy') {
  #  print "pf:$entry\t${db}:$id\n";
  #}
  elsif ($db eq 'interpro' || $db eq 'scop' || $db eq 'pdb' || $db eq 'tc') {
    print "pf:$entry\t${db}:$id\n";
  }
}

sub cc {
  my $s = shift;
  $s =~ s/\s+/ /gm;
  my @n = ($s =~ /\d+\.\d+\.\d+\.\d+/g);
  foreach my $e (@n) {
    print "pf:$entry\tec:$e\n";
  }
  @n = ($s =~ /PF\d{5}/g);
  foreach my $e (@n) {
    print "pf:$entry\tpf:$e\n";
  }
  @n = ($s =~ /Swiss:(\S+)/g);
  foreach my $e (@n) {
    $e =~ s/[\.\,\)\:]//g;
    if (isswiss($e)) {
      print "pf:$entry\tup:$e\n";
    }
  }
  @n = ($s =~ /Swiss\-?Prot:(\S+)/g);
  foreach my $e (@n) {
    $e =~ s/[\.\,\)\:]//g;
    if (isswiss($e)) {
      print "pf:$entry\tup:$e\n";
    }
  }
  @n = ($s =~ /UniProt:(\S+)/g);
  foreach my $e (@n) {
    $e =~ s/[\.\,\)\:]//g;
    if (isswiss($e)) {
      print "pf:$entry\tup:$e\n";
    }
  }
  @n = ($s =~ /UniProtKB:(\S+)/g);
  foreach my $e (@n) {
    $e =~ s/[\.\,\)\:]//g;
    if (isswiss($e)) {
      print "pf:$entry\tup:$e\n";
    }
  }
  @n = ($s =~ /PS\d{5}/g);
  foreach my $e (@n) {
    print "pf:$entry\tps:$e\n";
  }
  @n = ($s =~ /PDOC\d{5}/g);
  foreach my $e (@n) {
    print "pf:$entry\tpdoc:$e\n";
  }
  @n = ($s =~ /MIM:(\d+)/g);
  foreach my $e (@n) {
    print "pf:$entry\tomim:$e\n";
  }
  @n = ($s =~ /Genbank:(\S+)/g);
  foreach my $e (@n) {
    $e =~ s/[\.\,\)\:]//g;
    if (isgenbank($e)) {
      print "pf:$entry\tgb:$e\n";
    }
  }
  @n = ($s =~ /PDB:(\S+)/ig);
  foreach my $e (@n) {
    $e =~ s/[\.\,\)\:]//g;
    if (ispdb($e)) {
      print "pf:$entry\tpdb:$e\n";
    }
  }
}

sub gs {
  my $s = shift;
  if ($s =~ /^([^\/]+)/) {
    my $id = $1;
    if (isswiss($id)) {
      print "pf:$entry\tup:$id\n";
    }
  }
  if ($s =~ /DR PDB; +(\S+)/) {
    my $id = $1;
    if (ispdb($id)) {
      print "pf:$entry\tpdb:$id\n";
    }
  }
}

